//===============================================================================
// Copyright 2014 Alachisoft.  All rights reserved.
//===============================================================================


using System;
using System.IO;
using System.Data;
using Microsoft.Win32;
using System.Data.OleDb;
using System.Globalization;
using System.Collections;

//using Alachisoft.NCache.Web.Caching;

namespace CustomDependency.Business
{
	/// <summary>
	/// Class that helps read and write customer information to database Server using Oledb provider.
	/// </summary>
	[Serializable]
	public class OleDbDatasource
	{
		private OleDbConnection		_connection;
		private string _connString;
		
		public OleDbDatasource()
		{
			_connection = Connect();
		}

		public string ConnectionString 
		{
			get
			{
				return _connString;
			}
		}

		/// <summary>
		/// Establish connection with the datasource.
		/// </summary>
		/// <param name="connString"></param>
		public OleDbConnection Connect()
		{
			OleDbConnection connection = null;
			try
			{
				RegistryKey key = Registry.LocalMachine.OpenSubKey(@"Software\Alachisoft\NCache");
//				string DsFilePath = Path.Combine(key.GetValue("InstallDir").ToString(),
//					@"samples\northwinddb\northwind.mdb");
                _connString = System.Configuration.ConfigurationSettings.AppSettings["conn-string"].ToString();
            }
			catch(Exception e)
			{
				System.Diagnostics.Trace.WriteLine(e);
			}

			connection = new OleDbConnection(_connString);
		
			try
			{
				connection.Open();
				return connection;
			}
			catch(Exception ex)
			{
				System.Diagnostics.Debug.WriteLine(ex.Message);
				throw ex;
			}
		}

		/// <summary>
		/// Releases the connection.
		/// </summary>
		public void DisConnect()
		{
			if(_connection != null)
				_connection.Close();
		}

		/// <summary>
		/// Loads a <see cref="Customer"/> object from the datasource.
		/// </summary>
		/// <param name="key"></param>
		/// <returns></returns>
		public Product[] LoadProducts()
		{			
			OleDbDataReader reader = null;
			Product[] products = new Product[15];
			int i = 0;
			try
			{
				OleDbCommand cmd = _connection.CreateCommand();
				cmd.CommandText = String.Format(CultureInfo.InvariantCulture, 
					"Select ProductID, ProductName, UnitsInStock" + 
					" From Products where ProductID < 16");

				reader = cmd.ExecuteReader();
					
				while(reader.Read())
				{
					Product product = new Product();

					product.ProductID		= (int)reader["ProductID"];
					product.ProductName		= reader["ProductName"].ToString();
					product.UnitsAvailable	= Convert.ToInt32(reader["UnitsInStock"].ToString());
					
					products[i++] = product;
				}
				reader.Close();
			}
			catch(Exception e)
			{
				System.Diagnostics.Trace.WriteLine(e);
			}
			return products;
		}

		public void SetUnitsInStocks(int newVal)
		{
			try
			{
				OleDbCommand cmd = _connection.CreateCommand();
				cmd.CommandText = String.Format(CultureInfo.InvariantCulture,
					"Update Products "+
					"Set UnitsInStock = {0} "+
					"Where ProductID < {1}",
					newVal, 16);

				cmd.ExecuteNonQuery();
			}
			catch (Exception e)
			{
				System.Diagnostics.Trace.WriteLine(e);
			}
		}
	}
}
